        function getT(rr,cc){
       if(rr==3 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260616 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==3 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260616 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>46</strong> miembros: 34 <strong>control</strong><br>0,1,2,3,4,5,6,7,8,9,10,13,15,16,17,18,19,24,27,28,29,31,35,36,37,39,41,43,44,46,47,48,49,50';}
       if(rr==3 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260616 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 17 <br>11,12,14,20,21,22,23,25,26,30,32,33,34,38,40,42,45';}
       if(rr==17 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260616 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==17 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260616 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>46</strong> miembros: 34 <strong>control</strong><br>0,1,2,3,4,5,6,7,8,9,10,13,15,16,17,18,19,24,27,28,29,31,35,36,37,39,41,43,44,46,47,48,49,50';}
       if(rr==17 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260616 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 17 <br>11,12,14,20,21,22,23,25,26,30,32,33,34,38,40,42,45';}
       if(rr==19 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260616 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==19 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260616 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>46</strong> miembros: 34 <strong>control</strong><br>0,1,2,3,4,5,6,7,8,9,10,13,15,16,17,18,19,24,27,28,29,31,35,36,37,39,41,43,44,46,47,48,49,50';}
       if(rr==19 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260616 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 17 <br>11,12,14,20,21,22,23,25,26,30,32,33,34,38,40,42,45';}
       if(rr==20 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260616 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==20 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260616 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>46</strong> miembros: 34 <strong>control</strong><br>0,1,2,3,4,5,6,7,8,9,10,13,15,16,17,18,19,24,27,28,29,31,35,36,37,39,41,43,44,46,47,48,49,50';}
       if(rr==20 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260616 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 17 <br>11,12,14,20,21,22,23,25,26,30,32,33,34,38,40,42,45';}
       if(rr==21 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260616 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==21 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260616 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>46</strong> miembros: 34 <strong>control</strong><br>0,1,2,3,4,5,6,7,8,9,10,13,15,16,17,18,19,24,27,28,29,31,35,36,37,39,41,43,44,46,47,48,49,50';}
       if(rr==21 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260616 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 17 <br>11,12,14,20,21,22,23,25,26,30,32,33,34,38,40,42,45';}
       if(rr==22 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260616 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==22 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260616 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>46</strong> miembros: 34 <strong>control</strong><br>0,1,2,3,4,5,6,7,8,9,10,13,15,16,17,18,19,24,27,28,29,31,35,36,37,39,41,43,44,46,47,48,49,50';}
       if(rr==22 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260616 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 17 <br>11,12,14,20,21,22,23,25,26,30,32,33,34,38,40,42,45';}
}
